"""convert start end times format

Revision ID: 130b087bc274
Revises: 17154c80d885
Create Date: 2022-02-01 15:21:22.257972

"""
from dagster.core.storage.migration.utils import (
    add_run_record_start_end_timestamps,
    drop_run_record_start_end_timestamps,
)

# revision identifiers, used by Alembic.
revision = "130b087bc274"
down_revision = "17154c80d885"
branch_labels = None
depends_on = None


def upgrade():
    drop_run_record_start_end_timestamps()
    add_run_record_start_end_timestamps()


def downgrade():
    pass



"""add instigators table

Revision ID: 5b467f7af3f6
Revises: d538c9496c01
Create Date: 2022-03-18 16:17:20.338259

"""
from dagster.core.storage.migration.utils import create_instigators_table

# revision identifiers, used by Alembic.
revision = "5b467f7af3f6"
down_revision = "d538c9496c01"
branch_labels = None
depends_on = None


def upgrade():
    create_instigators_table()


def downgrade():
    pass



"""add tick selector index

Revision ID: d32d1d6de793
Revises: 5b467f7af3f6
Create Date: 2022-03-25 10:29:10.895341

"""
from dagster.core.storage.migration.utils import create_tick_selector_index

# revision identifiers, used by Alembic.
revision = "d32d1d6de793"
down_revision = "5b467f7af3f6"
branch_labels = None
depends_on = None


def upgrade():
    create_tick_selector_index()


def downgrade():
    pass
